@@ -7,17 +7,18 @@ use App::ClusterSSH::L10N;
 
 # Dont use SVN revision as it can cause problems
 use version;
-our $VERSION = version->new('0.01');
+our $VERSION = version->new('0.02');
 
 my $debug_level = 0;
 our $language = 'en';
 our $language_handle;
+our $app_configuration;
 
 sub new {
-    my ( $class, %args) = @_;
+    my ( $class, %args ) = @_;
 
     my $config = {
-        lang => 'en',
+        lang  => 'en',
         debug => 0,
         %args,
     };
@@ -27,8 +28,9 @@ sub new {
     $self->set_debug_level( $config->{debug} );
     $self->set_lang( $config->{lang} );
 
-    $self->debug( 7, 
-        $self->loc('Arguments to [_1]->new(): ', $class), 
+    $self->debug(
+        7,
+        $self->loc( 'Arguments to [_1]->new(): ', $class ),
         $self->_dump_args_hash(%args),
     );
 
@@ -69,11 +71,9 @@ sub loc {
 
 sub set_lang {
     my ( $self, $lang ) = @_;
-    $language=$lang;
+    $language = $lang;
     if ($self) {
-        $self->debug( 6, 
-            $self->loc('Setting language to "[_1]"', $lang ),
-        );
+        $self->debug( 6, $self->loc( 'Setting language to "[_1]"', $lang ), );
     }
     return $self;
 }
@@ -109,11 +109,39 @@ sub debug {
     return $self;
 }
 
+sub config {
+    my ($self) = @_;
+
+    if ( !$app_configuration ) {
+        croak( _translate('config has not yet been set') );
+    }
+
+    return $app_configuration;
+}
+
+sub set_config {
+    my ( $self, $config ) = @_;
+
+    if ($app_configuration) {
+        croak( _translate('config has already been set') );
+    }
+
+    if(!$config) { 
+        croak( _translate('passed config is empty'));
+    }
+
+    $self->debug( 3, _translate('Setting app configuration') );
+
+    $app_configuration = $config;
+
+    return $self;
+}
+
 1;
 
 =pod
 
-=head1 
+=head1 NAME
 
 App::ClusterSSH::Base
 
@@ -177,20 +205,31 @@ a wrapper to maketext in Locale::Maketext
 
 Output text on STDOUT.
 
+=item $config = $obj->config;
+
+Returns whatever configuration object has been set up.  Croaks if set_config
+hasnt been called
+
+=item $obj->set_config($config);
+
+Set the config to the given value - croaks if has already been called
+
 =back
 
 =head1 AUTHOR
 
-Duncan Ferguson (<duncan_j_ferguson (at) yahoo.co.uk>)
+Duncan Ferguson, C<< <duncan_j_ferguson at yahoo.co.uk> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2009 Duncan Ferguson (<duncan_j_ferguson (at) yahoo.co.uk>). 
-All rights reserved
+Copyright 1999-2010 Duncan Ferguson.
 
-This module is free software; you can redistribute it and/or
-modify it under the same terms as Perl itself.  See L<perlartistic>.
+This program is free software; you can redistribute it and/or modify it
+under the terms of either: the GNU General Public License as published
+by the Free Software Foundation; or the Artistic License.
 
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+See http://dev.perl.org/licenses/ for more information.
+
+=cut
+
+1;
